==> wheezy.validation-0.1.146.tar.gz: wheezy.validation-0.1.146/README.md <==
# wheezy.validation

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.validation.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.validation)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.validation/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.validation?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezyvalidation/badge/?version=latest)](https://wheezyvalidation.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.validation.svg)](https://badge.fury.io/py/wheezy.validation)

[wheezy.validation](https://pypi.org/project/wheezy.validation/) is a
[python](https://www.python.org) package written in pure Python code. It
provides python object validation.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.validation)
  and [issues](https://github.com/akornatskyy/wheezy.validation/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.validation)
- [documentation](https://wheezyvalidation.readthedocs.io/en/latest/)

## Install

[wheezy.validation](https://pypi.org/project/wheezy.validation/)
requires [python](https://www.python.org) version 2.4 to 2.7 or 3.2+. It
is independent of operating system. You can install it from
[pypi](https://pypi.org/project/wheezy.validation/):

```sh
pip install -U wheezy.validation
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyywheezy.validation).

==> wheezy.validation-3.0.1.tar.gz: wheezy.validation-3.0.1/README.md <==
# wheezy.validation

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.validation.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.validation)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.validation/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.validation?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezyvalidation/badge/?version=latest)](https://wheezyvalidation.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.validation.svg)](https://badge.fury.io/py/wheezy.validation)

[wheezy.validation](https://pypi.org/project/wheezy.validation/) is a
[python](https://www.python.org) package written in pure Python code. It
provides python object validation.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.validation)
  and [issues](https://github.com/akornatskyy/wheezy.validation/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.validation)
- [documentation](https://wheezyvalidation.readthedocs.io/en/latest/)

## Install

[wheezy.validation](https://pypi.org/project/wheezy.validation/)
requires [python](https://www.python.org) version 3.6+. It is independent of
operating system. You can install it from
[pypi](https://pypi.org/project/wheezy.validation/):

```sh
pip install -U wheezy.validation
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyywheezy.validation).
